==> pylocateme-0.1.tar.gz: pylocateme-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'pylocateme',         # How you named your package folder (MyLib)
  packages = ['pylocateme'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A python tool to find information of a place in a country using two or one line of code',   # Give a short description about your library
  author = 'LEISUREZONEPYTHONTUTORIALS',                   # Type in your name
  author_email = 'leisurezoneofficial@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/user/reponame',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['LOCATION', 'WORLDWIDE PLACES', 'WORLDWIDE COUNTRIES'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'geopy',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3', #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.1',
    'Programming Language :: Python :: 3.2',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)

==> pylocateme-0.2.tar.gz: pylocateme-0.2/setup.py <==
from distutils.core import setup
setup(
  name = 'pylocateme',         # How you named your package folder (MyLib)
  packages = ['pylocateme'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'A python tool to find information of a place in a country using two or one line of code',   # Give a short description about your library
  author = 'LEISUREZONEPYTHONTUTORIALS',                   # Type in your name
  author_email = 'leisurezoneofficial@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/LEISUREZONEPYTHONTUTORIALS/pylocateme',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/LEISUREZONEPYTHONTUTORIALS/pylocateme/archive/refs/tags/0.1.tar.gz',    # I explain this later on
  keywords = ['LOCATION', 'WORLDWIDE PLACES', 'WORLDWIDE COUNTRIES'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'geopy',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3', #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.1',
    'Programming Language :: Python :: 3.2',
    'Programming Language :: Python :: 3.3',
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
    'Programming Language :: Python :: 3.9',
  ],
)
